# coding: utf-8

"""
    Timeline

    This feature allows an app to create and configure custom events that can show up in the timelines of certain CRM objects like contacts, companies, tickets, or deals. You'll find multiple use cases for this API in the sections below.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.crm.timeline.api_client import ApiClient
from hubspot.crm.timeline.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class TemplatesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive(self, event_template_id, app_id, **kwargs):  # noqa: E501
        """Deletes an event template for the app  # noqa: E501

        This will delete the event template. All associated events will be removed from search results and the timeline UI.  This action can't be undone, so it's highly recommended that you stop using any associated events before deleting a template.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive(event_template_id, app_id, async_req=True)
        >>> result = thread.get()

        :param event_template_id: The event template ID. (required)
        :type event_template_id: str
        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_with_http_info(event_template_id, app_id, **kwargs)  # noqa: E501

    def archive_with_http_info(self, event_template_id, app_id, **kwargs):  # noqa: E501
        """Deletes an event template for the app  # noqa: E501

        This will delete the event template. All associated events will be removed from search results and the timeline UI.  This action can't be undone, so it's highly recommended that you stop using any associated events before deleting a template.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_with_http_info(event_template_id, app_id, async_req=True)
        >>> result = thread.get()

        :param event_template_id: The event template ID. (required)
        :type event_template_id: str
        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["event_template_id", "app_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'event_template_id' is set
        if self.api_client.client_side_validation and local_var_params.get("event_template_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `event_template_id` when calling `archive`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `archive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "event_template_id" in local_var_params:
            path_params["eventTemplateId"] = local_var_params["event_template_id"]  # noqa: E501
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/integrators/timeline/v3/{appId}/event-templates/{eventTemplateId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create(self, app_id, timeline_event_template_create_request, **kwargs):  # noqa: E501
        """Create an event template for your app  # noqa: E501

        Event templates define the general structure for a custom timeline event. This includes formatted copy for its heading and details, as well as any custom property definitions. The event could be something like viewing a video, registering for a webinar, or filling out a survey. A single app can define multiple event templates.  Event templates will be created for contacts by default, but they can be created for companies, tickets, and deals as well.  Each event template contains its own set of tokens and `Markdown` templates. These tokens can be associated with any CRM object properties via the `objectPropertyName` field to fully build out CRM objects.  You must create an event template before you can create events.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(app_id, timeline_event_template_create_request, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param timeline_event_template_create_request: The new event template definition. (required)
        :type timeline_event_template_create_request: TimelineEventTemplateCreateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TimelineEventTemplate
        """
        kwargs["_return_http_data_only"] = True
        return self.create_with_http_info(app_id, timeline_event_template_create_request, **kwargs)  # noqa: E501

    def create_with_http_info(self, app_id, timeline_event_template_create_request, **kwargs):  # noqa: E501
        """Create an event template for your app  # noqa: E501

        Event templates define the general structure for a custom timeline event. This includes formatted copy for its heading and details, as well as any custom property definitions. The event could be something like viewing a video, registering for a webinar, or filling out a survey. A single app can define multiple event templates.  Event templates will be created for contacts by default, but they can be created for companies, tickets, and deals as well.  Each event template contains its own set of tokens and `Markdown` templates. These tokens can be associated with any CRM object properties via the `objectPropertyName` field to fully build out CRM objects.  You must create an event template before you can create events.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(app_id, timeline_event_template_create_request, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param timeline_event_template_create_request: The new event template definition. (required)
        :type timeline_event_template_create_request: TimelineEventTemplateCreateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(TimelineEventTemplate, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["app_id", "timeline_event_template_create_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `create`")  # noqa: E501
        # verify the required parameter 'timeline_event_template_create_request' is set
        if self.api_client.client_side_validation and local_var_params.get("timeline_event_template_create_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `timeline_event_template_create_request` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "timeline_event_template_create_request" in local_var_params:
            body_params = local_var_params["timeline_event_template_create_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            201: "TimelineEventTemplate",
        }

        return self.api_client.call_api(
            "/integrators/timeline/v3/{appId}/event-templates",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_all(self, app_id, **kwargs):  # noqa: E501
        """List all event templates for your app  # noqa: E501

        Use this to list all event templates owned by your app.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CollectionResponseTimelineEventTemplateNoPaging
        """
        kwargs["_return_http_data_only"] = True
        return self.get_all_with_http_info(app_id, **kwargs)  # noqa: E501

    def get_all_with_http_info(self, app_id, **kwargs):  # noqa: E501
        """List all event templates for your app  # noqa: E501

        Use this to list all event templates owned by your app.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all_with_http_info(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CollectionResponseTimelineEventTemplateNoPaging, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["app_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_all" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `get_all`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            200: "CollectionResponseTimelineEventTemplateNoPaging",
        }

        return self.api_client.call_api(
            "/integrators/timeline/v3/{appId}/event-templates",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_by_id(self, event_template_id, app_id, **kwargs):  # noqa: E501
        """Gets a specific event template for your app  # noqa: E501

        View the current state of a specific template and its tokens.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id(event_template_id, app_id, async_req=True)
        >>> result = thread.get()

        :param event_template_id: The event template ID. (required)
        :type event_template_id: str
        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TimelineEventTemplate
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_id_with_http_info(event_template_id, app_id, **kwargs)  # noqa: E501

    def get_by_id_with_http_info(self, event_template_id, app_id, **kwargs):  # noqa: E501
        """Gets a specific event template for your app  # noqa: E501

        View the current state of a specific template and its tokens.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id_with_http_info(event_template_id, app_id, async_req=True)
        >>> result = thread.get()

        :param event_template_id: The event template ID. (required)
        :type event_template_id: str
        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(TimelineEventTemplate, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["event_template_id", "app_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'event_template_id' is set
        if self.api_client.client_side_validation and local_var_params.get("event_template_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `event_template_id` when calling `get_by_id`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `get_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "event_template_id" in local_var_params:
            path_params["eventTemplateId"] = local_var_params["event_template_id"]  # noqa: E501
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            200: "TimelineEventTemplate",
        }

        return self.api_client.call_api(
            "/integrators/timeline/v3/{appId}/event-templates/{eventTemplateId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update(self, event_template_id, app_id, timeline_event_template_update_request, **kwargs):  # noqa: E501
        """Update an existing event template  # noqa: E501

        Updates an existing template and its tokens. This is primarily used to update the headerTemplate/detailTemplate, and those changes will take effect for existing events.  You can also update or replace all the tokens in the template here instead of doing individual API calls on the `/tokens` endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update(event_template_id, app_id, timeline_event_template_update_request, async_req=True)
        >>> result = thread.get()

        :param event_template_id: The event template ID. (required)
        :type event_template_id: str
        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param timeline_event_template_update_request: The updated event template definition. (required)
        :type timeline_event_template_update_request: TimelineEventTemplateUpdateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TimelineEventTemplate
        """
        kwargs["_return_http_data_only"] = True
        return self.update_with_http_info(event_template_id, app_id, timeline_event_template_update_request, **kwargs)  # noqa: E501

    def update_with_http_info(self, event_template_id, app_id, timeline_event_template_update_request, **kwargs):  # noqa: E501
        """Update an existing event template  # noqa: E501

        Updates an existing template and its tokens. This is primarily used to update the headerTemplate/detailTemplate, and those changes will take effect for existing events.  You can also update or replace all the tokens in the template here instead of doing individual API calls on the `/tokens` endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_with_http_info(event_template_id, app_id, timeline_event_template_update_request, async_req=True)
        >>> result = thread.get()

        :param event_template_id: The event template ID. (required)
        :type event_template_id: str
        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param timeline_event_template_update_request: The updated event template definition. (required)
        :type timeline_event_template_update_request: TimelineEventTemplateUpdateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(TimelineEventTemplate, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["event_template_id", "app_id", "timeline_event_template_update_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'event_template_id' is set
        if self.api_client.client_side_validation and local_var_params.get("event_template_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `event_template_id` when calling `update`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `update`")  # noqa: E501
        # verify the required parameter 'timeline_event_template_update_request' is set
        if self.api_client.client_side_validation and local_var_params.get("timeline_event_template_update_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `timeline_event_template_update_request` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "event_template_id" in local_var_params:
            path_params["eventTemplateId"] = local_var_params["event_template_id"]  # noqa: E501
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "timeline_event_template_update_request" in local_var_params:
            body_params = local_var_params["timeline_event_template_update_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            200: "TimelineEventTemplate",
        }

        return self.api_client.call_api(
            "/integrators/timeline/v3/{appId}/event-templates/{eventTemplateId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



import hubspot.marketing.events as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def add_event_attendees_api(self) -> api_client.AddEventAttendeesApi:
        return self._configure_api_client(api_client, "AddEventAttendeesApi")

    @property
    def basic_api(self) -> api_client.BasicApi:
        return self._configure_api_client(api_client, "BasicApi")

    @property
    def batch_api(self) -> api_client.BatchApi:
        return self._configure_api_client(api_client, "BatchApi")

    @property
    def change_property_api(self) -> api_client.ChangePropertyApi:
        return self._configure_api_client(api_client, "ChangePropertyApi")

    @property
    def identifiers_api(self) -> api_client.IdentifiersApi:
        return self._configure_api_client(api_client, "IdentifiersApi")

    @property
    def list_associations_api(self) -> api_client.ListAssociationsApi:
        return self._configure_api_client(api_client, "ListAssociationsApi")

    @property
    def retrieve_participant_state_api(self) -> api_client.RetrieveParticipantStateApi:
        return self._configure_api_client(api_client, "RetrieveParticipantStateApi")

    @property
    def settings_api(self) -> api_client.SettingsApi:
        return self._configure_api_client(api_client, "SettingsApi")

    @property
    def subscriber_state_changes_api(self) -> api_client.SubscriberStateChangesApi:
        return self._configure_api_client(api_client, "SubscriberStateChangesApi")



from ..discovery_base import DiscoveryBase

class Discovery(DiscoveryBase):
    @property
    def emails(self):
        from .emails.discovery import Discovery as EmailsDiscovery
        return EmailsDiscovery(self.config)

    @property
    def events(self):
        from .events.discovery import Discovery as EventsDiscovery
        return EventsDiscovery(self.config)

    @property
    def forms(self):
        from .forms.discovery import Discovery as FormsDiscovery
        return FormsDiscovery(self.config)

    @property
    def transactional(self):
        from .transactional.discovery import Discovery as TransactionalDiscovery
        return TransactionalDiscovery(self.config)



# coding: utf-8

"""
    Files

    Upload and manage files.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.files.configuration import Configuration


class File(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "extension": "str",
        "access": "str",
        "parent_folder_id": "str",
        "source_group": "str",
        "file_md5": "str",
        "encoding": "str",
        "type": "str",
        "is_usable_in_content": "bool",
        "url": "str",
        "expires_at": "int",
        "created_at": "datetime",
        "archived_at": "datetime",
        "path": "str",
        "archived": "bool",
        "size": "int",
        "name": "str",
        "width": "int",
        "id": "str",
        "default_hosting_url": "str",
        "updated_at": "datetime",
        "height": "int",
    }

    attribute_map = {
        "extension": "extension",
        "access": "access",
        "parent_folder_id": "parentFolderId",
        "source_group": "sourceGroup",
        "file_md5": "fileMd5",
        "encoding": "encoding",
        "type": "type",
        "is_usable_in_content": "isUsableInContent",
        "url": "url",
        "expires_at": "expiresAt",
        "created_at": "createdAt",
        "archived_at": "archivedAt",
        "path": "path",
        "archived": "archived",
        "size": "size",
        "name": "name",
        "width": "width",
        "id": "id",
        "default_hosting_url": "defaultHostingUrl",
        "updated_at": "updatedAt",
        "height": "height",
    }

    def __init__(
        self,
        extension=None,
        access=None,
        parent_folder_id=None,
        source_group=None,
        file_md5=None,
        encoding=None,
        type=None,
        is_usable_in_content=None,
        url=None,
        expires_at=None,
        created_at=None,
        archived_at=None,
        path=None,
        archived=None,
        size=None,
        name=None,
        width=None,
        id=None,
        default_hosting_url=None,
        updated_at=None,
        height=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """File - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._extension = None
        self._access = None
        self._parent_folder_id = None
        self._source_group = None
        self._file_md5 = None
        self._encoding = None
        self._type = None
        self._is_usable_in_content = None
        self._url = None
        self._expires_at = None
        self._created_at = None
        self._archived_at = None
        self._path = None
        self._archived = None
        self._size = None
        self._name = None
        self._width = None
        self._id = None
        self._default_hosting_url = None
        self._updated_at = None
        self._height = None
        self.discriminator = None

        if extension is not None:
            self.extension = extension
        self.access = access
        if parent_folder_id is not None:
            self.parent_folder_id = parent_folder_id
        if source_group is not None:
            self.source_group = source_group
        if file_md5 is not None:
            self.file_md5 = file_md5
        if encoding is not None:
            self.encoding = encoding
        if type is not None:
            self.type = type
        if is_usable_in_content is not None:
            self.is_usable_in_content = is_usable_in_content
        if url is not None:
            self.url = url
        if expires_at is not None:
            self.expires_at = expires_at
        self.created_at = created_at
        if archived_at is not None:
            self.archived_at = archived_at
        if path is not None:
            self.path = path
        self.archived = archived
        if size is not None:
            self.size = size
        if name is not None:
            self.name = name
        if width is not None:
            self.width = width
        self.id = id
        if default_hosting_url is not None:
            self.default_hosting_url = default_hosting_url
        self.updated_at = updated_at
        if height is not None:
            self.height = height

    @property
    def extension(self):
        """Gets the extension of this File.  # noqa: E501

        Extension of the file. ex: .jpg, .png, .gif, .pdf, etc.  # noqa: E501

        :return: The extension of this File.  # noqa: E501
        :rtype: str
        """
        return self._extension

    @extension.setter
    def extension(self, extension):
        """Sets the extension of this File.

        Extension of the file. ex: .jpg, .png, .gif, .pdf, etc.  # noqa: E501

        :param extension: The extension of this File.  # noqa: E501
        :type extension: str
        """

        self._extension = extension

    @property
    def access(self):
        """Gets the access of this File.  # noqa: E501

        File access. Can be PUBLIC_INDEXABLE, PUBLIC_NOT_INDEXABLE, PRIVATE.  # noqa: E501

        :return: The access of this File.  # noqa: E501
        :rtype: str
        """
        return self._access

    @access.setter
    def access(self, access):
        """Sets the access of this File.

        File access. Can be PUBLIC_INDEXABLE, PUBLIC_NOT_INDEXABLE, PRIVATE.  # noqa: E501

        :param access: The access of this File.  # noqa: E501
        :type access: str
        """
        if self.local_vars_configuration.client_side_validation and access is None:  # noqa: E501
            raise ValueError("Invalid value for `access`, must not be `None`")  # noqa: E501
        allowed_values = ["PUBLIC_INDEXABLE", "PUBLIC_NOT_INDEXABLE", "HIDDEN_INDEXABLE", "HIDDEN_NOT_INDEXABLE", "HIDDEN_PRIVATE", "PRIVATE", "HIDDEN_SENSITIVE", "SENSITIVE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and access not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `access` ({0}), must be one of {1}".format(access, allowed_values))  # noqa: E501

        self._access = access

    @property
    def parent_folder_id(self):
        """Gets the parent_folder_id of this File.  # noqa: E501

        ID of the folder the file is in.  # noqa: E501

        :return: The parent_folder_id of this File.  # noqa: E501
        :rtype: str
        """
        return self._parent_folder_id

    @parent_folder_id.setter
    def parent_folder_id(self, parent_folder_id):
        """Sets the parent_folder_id of this File.

        ID of the folder the file is in.  # noqa: E501

        :param parent_folder_id: The parent_folder_id of this File.  # noqa: E501
        :type parent_folder_id: str
        """

        self._parent_folder_id = parent_folder_id

    @property
    def source_group(self):
        """Gets the source_group of this File.  # noqa: E501


        :return: The source_group of this File.  # noqa: E501
        :rtype: str
        """
        return self._source_group

    @source_group.setter
    def source_group(self, source_group):
        """Sets the source_group of this File.


        :param source_group: The source_group of this File.  # noqa: E501
        :type source_group: str
        """

        self._source_group = source_group

    @property
    def file_md5(self):
        """Gets the file_md5 of this File.  # noqa: E501


        :return: The file_md5 of this File.  # noqa: E501
        :rtype: str
        """
        return self._file_md5

    @file_md5.setter
    def file_md5(self, file_md5):
        """Sets the file_md5 of this File.


        :param file_md5: The file_md5 of this File.  # noqa: E501
        :type file_md5: str
        """

        self._file_md5 = file_md5

    @property
    def encoding(self):
        """Gets the encoding of this File.  # noqa: E501

        Encoding of the file.  # noqa: E501

        :return: The encoding of this File.  # noqa: E501
        :rtype: str
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        """Sets the encoding of this File.

        Encoding of the file.  # noqa: E501

        :param encoding: The encoding of this File.  # noqa: E501
        :type encoding: str
        """

        self._encoding = encoding

    @property
    def type(self):
        """Gets the type of this File.  # noqa: E501

        Type of the file. Can be IMG, DOCUMENT, AUDIO, MOVIE, or OTHER.  # noqa: E501

        :return: The type of this File.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this File.

        Type of the file. Can be IMG, DOCUMENT, AUDIO, MOVIE, or OTHER.  # noqa: E501

        :param type: The type of this File.  # noqa: E501
        :type type: str
        """

        self._type = type

    @property
    def is_usable_in_content(self):
        """Gets the is_usable_in_content of this File.  # noqa: E501

        Previously \"archied\". Indicates if the file should be used when creating new content like web pages.  # noqa: E501

        :return: The is_usable_in_content of this File.  # noqa: E501
        :rtype: bool
        """
        return self._is_usable_in_content

    @is_usable_in_content.setter
    def is_usable_in_content(self, is_usable_in_content):
        """Sets the is_usable_in_content of this File.

        Previously \"archied\". Indicates if the file should be used when creating new content like web pages.  # noqa: E501

        :param is_usable_in_content: The is_usable_in_content of this File.  # noqa: E501
        :type is_usable_in_content: bool
        """

        self._is_usable_in_content = is_usable_in_content

    @property
    def url(self):
        """Gets the url of this File.  # noqa: E501

        URL of the given file. This URL can change depending on the domain settings of the account. Will use the select file hosting domain.  # noqa: E501

        :return: The url of this File.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this File.

        URL of the given file. This URL can change depending on the domain settings of the account. Will use the select file hosting domain.  # noqa: E501

        :param url: The url of this File.  # noqa: E501
        :type url: str
        """

        self._url = url

    @property
    def expires_at(self):
        """Gets the expires_at of this File.  # noqa: E501


        :return: The expires_at of this File.  # noqa: E501
        :rtype: int
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this File.


        :param expires_at: The expires_at of this File.  # noqa: E501
        :type expires_at: int
        """

        self._expires_at = expires_at

    @property
    def created_at(self):
        """Gets the created_at of this File.  # noqa: E501

        Creation time of the file object.  # noqa: E501

        :return: The created_at of this File.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this File.

        Creation time of the file object.  # noqa: E501

        :param created_at: The created_at of this File.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def archived_at(self):
        """Gets the archived_at of this File.  # noqa: E501

        Deletion time of the file object.  # noqa: E501

        :return: The archived_at of this File.  # noqa: E501
        :rtype: datetime
        """
        return self._archived_at

    @archived_at.setter
    def archived_at(self, archived_at):
        """Sets the archived_at of this File.

        Deletion time of the file object.  # noqa: E501

        :param archived_at: The archived_at of this File.  # noqa: E501
        :type archived_at: datetime
        """

        self._archived_at = archived_at

    @property
    def path(self):
        """Gets the path of this File.  # noqa: E501

        Path of the file in the file manager.  # noqa: E501

        :return: The path of this File.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this File.

        Path of the file in the file manager.  # noqa: E501

        :param path: The path of this File.  # noqa: E501
        :type path: str
        """

        self._path = path

    @property
    def archived(self):
        """Gets the archived of this File.  # noqa: E501

        If the file is deleted.  # noqa: E501

        :return: The archived of this File.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this File.

        If the file is deleted.  # noqa: E501

        :param archived: The archived of this File.  # noqa: E501
        :type archived: bool
        """
        if self.local_vars_configuration.client_side_validation and archived is None:  # noqa: E501
            raise ValueError("Invalid value for `archived`, must not be `None`")  # noqa: E501

        self._archived = archived

    @property
    def size(self):
        """Gets the size of this File.  # noqa: E501

        Size of the file in bytes.  # noqa: E501

        :return: The size of this File.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this File.

        Size of the file in bytes.  # noqa: E501

        :param size: The size of this File.  # noqa: E501
        :type size: int
        """

        self._size = size

    @property
    def name(self):
        """Gets the name of this File.  # noqa: E501

        Name of the file.  # noqa: E501

        :return: The name of this File.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this File.

        Name of the file.  # noqa: E501

        :param name: The name of this File.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def width(self):
        """Gets the width of this File.  # noqa: E501

        For image and video files, the width of the content.  # noqa: E501

        :return: The width of this File.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this File.

        For image and video files, the width of the content.  # noqa: E501

        :param width: The width of this File.  # noqa: E501
        :type width: int
        """

        self._width = width

    @property
    def id(self):
        """Gets the id of this File.  # noqa: E501

        File ID.  # noqa: E501

        :return: The id of this File.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this File.

        File ID.  # noqa: E501

        :param id: The id of this File.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def default_hosting_url(self):
        """Gets the default_hosting_url of this File.  # noqa: E501

        Default hosting URL of the file. This will use one of HubSpot's provided URLs to serve the file.  # noqa: E501

        :return: The default_hosting_url of this File.  # noqa: E501
        :rtype: str
        """
        return self._default_hosting_url

    @default_hosting_url.setter
    def default_hosting_url(self, default_hosting_url):
        """Sets the default_hosting_url of this File.

        Default hosting URL of the file. This will use one of HubSpot's provided URLs to serve the file.  # noqa: E501

        :param default_hosting_url: The default_hosting_url of this File.  # noqa: E501
        :type default_hosting_url: str
        """

        self._default_hosting_url = default_hosting_url

    @property
    def updated_at(self):
        """Gets the updated_at of this File.  # noqa: E501

        Timestamp of the latest update to the file.  # noqa: E501

        :return: The updated_at of this File.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this File.

        Timestamp of the latest update to the file.  # noqa: E501

        :param updated_at: The updated_at of this File.  # noqa: E501
        :type updated_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def height(self):
        """Gets the height of this File.  # noqa: E501

        For image and video files, the height of the content.  # noqa: E501

        :return: The height of this File.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this File.

        For image and video files, the height of the content.  # noqa: E501

        :param height: The height of this File.  # noqa: E501
        :type height: int
        """

        self._height = height

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, File):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, File):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Associations

    Associations define the relationships between objects in HubSpot. These endpoints allow you to create, read, and remove associations.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.associations.configuration import Configuration


class BatchResponsePublicAssociationWithErrors(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "completed_at": "datetime",
        "num_errors": "int",
        "requested_at": "datetime",
        "started_at": "datetime",
        "links": "dict[str, str]",
        "results": "list[PublicAssociation]",
        "errors": "list[StandardError]",
        "status": "str",
    }

    attribute_map = {
        "completed_at": "completedAt",
        "num_errors": "numErrors",
        "requested_at": "requestedAt",
        "started_at": "startedAt",
        "links": "links",
        "results": "results",
        "errors": "errors",
        "status": "status",
    }

    def __init__(self, completed_at=None, num_errors=None, requested_at=None, started_at=None, links=None, results=None, errors=None, status=None, local_vars_configuration=None):  # noqa: E501
        """BatchResponsePublicAssociationWithErrors - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._completed_at = None
        self._num_errors = None
        self._requested_at = None
        self._started_at = None
        self._links = None
        self._results = None
        self._errors = None
        self._status = None
        self.discriminator = None

        self.completed_at = completed_at
        if num_errors is not None:
            self.num_errors = num_errors
        if requested_at is not None:
            self.requested_at = requested_at
        self.started_at = started_at
        if links is not None:
            self.links = links
        self.results = results
        if errors is not None:
            self.errors = errors
        self.status = status

    @property
    def completed_at(self):
        """Gets the completed_at of this BatchResponsePublicAssociationWithErrors.  # noqa: E501


        :return: The completed_at of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :rtype: datetime
        """
        return self._completed_at

    @completed_at.setter
    def completed_at(self, completed_at):
        """Sets the completed_at of this BatchResponsePublicAssociationWithErrors.


        :param completed_at: The completed_at of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :type completed_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and completed_at is None:  # noqa: E501
            raise ValueError("Invalid value for `completed_at`, must not be `None`")  # noqa: E501

        self._completed_at = completed_at

    @property
    def num_errors(self):
        """Gets the num_errors of this BatchResponsePublicAssociationWithErrors.  # noqa: E501


        :return: The num_errors of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :rtype: int
        """
        return self._num_errors

    @num_errors.setter
    def num_errors(self, num_errors):
        """Sets the num_errors of this BatchResponsePublicAssociationWithErrors.


        :param num_errors: The num_errors of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :type num_errors: int
        """

        self._num_errors = num_errors

    @property
    def requested_at(self):
        """Gets the requested_at of this BatchResponsePublicAssociationWithErrors.  # noqa: E501


        :return: The requested_at of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :rtype: datetime
        """
        return self._requested_at

    @requested_at.setter
    def requested_at(self, requested_at):
        """Sets the requested_at of this BatchResponsePublicAssociationWithErrors.


        :param requested_at: The requested_at of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :type requested_at: datetime
        """

        self._requested_at = requested_at

    @property
    def started_at(self):
        """Gets the started_at of this BatchResponsePublicAssociationWithErrors.  # noqa: E501


        :return: The started_at of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this BatchResponsePublicAssociationWithErrors.


        :param started_at: The started_at of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :type started_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and started_at is None:  # noqa: E501
            raise ValueError("Invalid value for `started_at`, must not be `None`")  # noqa: E501

        self._started_at = started_at

    @property
    def links(self):
        """Gets the links of this BatchResponsePublicAssociationWithErrors.  # noqa: E501


        :return: The links of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this BatchResponsePublicAssociationWithErrors.


        :param links: The links of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :type links: dict[str, str]
        """

        self._links = links

    @property
    def results(self):
        """Gets the results of this BatchResponsePublicAssociationWithErrors.  # noqa: E501


        :return: The results of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :rtype: list[PublicAssociation]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this BatchResponsePublicAssociationWithErrors.


        :param results: The results of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :type results: list[PublicAssociation]
        """
        if self.local_vars_configuration.client_side_validation and results is None:  # noqa: E501
            raise ValueError("Invalid value for `results`, must not be `None`")  # noqa: E501

        self._results = results

    @property
    def errors(self):
        """Gets the errors of this BatchResponsePublicAssociationWithErrors.  # noqa: E501


        :return: The errors of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :rtype: list[StandardError]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this BatchResponsePublicAssociationWithErrors.


        :param errors: The errors of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :type errors: list[StandardError]
        """

        self._errors = errors

    @property
    def status(self):
        """Gets the status of this BatchResponsePublicAssociationWithErrors.  # noqa: E501


        :return: The status of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BatchResponsePublicAssociationWithErrors.


        :param status: The status of this BatchResponsePublicAssociationWithErrors.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["PENDING", "PROCESSING", "CANCELED", "COMPLETE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `status` ({0}), must be one of {1}".format(status, allowed_values))  # noqa: E501

        self._status = status

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchResponsePublicAssociationWithErrors):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BatchResponsePublicAssociationWithErrors):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    CRM Exports

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.exports.api.public_exports_api import PublicExportsApi

# import ApiClient
from hubspot.crm.exports.api_client import ApiClient
from hubspot.crm.exports.configuration import Configuration
from hubspot.crm.exports.exceptions import OpenApiException
from hubspot.crm.exports.exceptions import ApiTypeError
from hubspot.crm.exports.exceptions import ApiValueError
from hubspot.crm.exports.exceptions import ApiKeyError
from hubspot.crm.exports.exceptions import ApiAttributeError
from hubspot.crm.exports.exceptions import ApiException

# import models into sdk package
from hubspot.crm.exports.models.action_response_with_single_result_uri import ActionResponseWithSingleResultURI
from hubspot.crm.exports.models.error import Error
from hubspot.crm.exports.models.error_detail import ErrorDetail
from hubspot.crm.exports.models.filter import Filter
from hubspot.crm.exports.models.public_crm_search_request import PublicCrmSearchRequest
from hubspot.crm.exports.models.public_export_list_request import PublicExportListRequest
from hubspot.crm.exports.models.public_export_list_request_all_of import PublicExportListRequestAllOf
from hubspot.crm.exports.models.public_export_request import PublicExportRequest
from hubspot.crm.exports.models.public_export_view_request import PublicExportViewRequest
from hubspot.crm.exports.models.public_export_view_request_all_of import PublicExportViewRequestAllOf
from hubspot.crm.exports.models.standard_error import StandardError
from hubspot.crm.exports.models.task_locator import TaskLocator



# coding: utf-8

# flake8: noqa

"""
    Hubdb

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.cms.hubdb.api.rows_api import RowsApi
from hubspot.cms.hubdb.api.rows_batch_api import RowsBatchApi
from hubspot.cms.hubdb.api.tables_api import TablesApi

# import ApiClient
from hubspot.cms.hubdb.api_client import ApiClient
from hubspot.cms.hubdb.configuration import Configuration
from hubspot.cms.hubdb.exceptions import OpenApiException
from hubspot.cms.hubdb.exceptions import ApiTypeError
from hubspot.cms.hubdb.exceptions import ApiValueError
from hubspot.cms.hubdb.exceptions import ApiKeyError
from hubspot.cms.hubdb.exceptions import ApiAttributeError
from hubspot.cms.hubdb.exceptions import ApiException

# import models into sdk package
from hubspot.cms.hubdb.models.batch_input_hub_db_table_row_batch_clone_request import BatchInputHubDbTableRowBatchCloneRequest
from hubspot.cms.hubdb.models.batch_input_hub_db_table_row_v3_batch_update_request import BatchInputHubDbTableRowV3BatchUpdateRequest
from hubspot.cms.hubdb.models.batch_input_hub_db_table_row_v3_request import BatchInputHubDbTableRowV3Request
from hubspot.cms.hubdb.models.batch_input_string import BatchInputString
from hubspot.cms.hubdb.models.batch_response_hub_db_table_row_v3 import BatchResponseHubDbTableRowV3
from hubspot.cms.hubdb.models.batch_response_hub_db_table_row_v3_with_errors import BatchResponseHubDbTableRowV3WithErrors
from hubspot.cms.hubdb.models.bounded_next_page import BoundedNextPage
from hubspot.cms.hubdb.models.bounded_paging import BoundedPaging
from hubspot.cms.hubdb.models.collection_response_with_total_hub_db_table_v3_forward_paging import CollectionResponseWithTotalHubDbTableV3ForwardPaging
from hubspot.cms.hubdb.models.column import Column
from hubspot.cms.hubdb.models.column_request import ColumnRequest
from hubspot.cms.hubdb.models.error import Error
from hubspot.cms.hubdb.models.error_detail import ErrorDetail
from hubspot.cms.hubdb.models.foreign_id import ForeignId
from hubspot.cms.hubdb.models.forward_paging import ForwardPaging
from hubspot.cms.hubdb.models.hub_db_table_clone_request import HubDbTableCloneRequest
from hubspot.cms.hubdb.models.hub_db_table_row_batch_clone_request import HubDbTableRowBatchCloneRequest
from hubspot.cms.hubdb.models.hub_db_table_row_v3 import HubDbTableRowV3
from hubspot.cms.hubdb.models.hub_db_table_row_v3_batch_update_request import HubDbTableRowV3BatchUpdateRequest
from hubspot.cms.hubdb.models.hub_db_table_row_v3_request import HubDbTableRowV3Request
from hubspot.cms.hubdb.models.hub_db_table_v3 import HubDbTableV3
from hubspot.cms.hubdb.models.hub_db_table_v3_request import HubDbTableV3Request
from hubspot.cms.hubdb.models.import_result import ImportResult
from hubspot.cms.hubdb.models.next_page import NextPage
from hubspot.cms.hubdb.models.option import Option
from hubspot.cms.hubdb.models.paging import Paging
from hubspot.cms.hubdb.models.previous_page import PreviousPage
from hubspot.cms.hubdb.models.random_access_collection_response_with_total_hub_db_table_row_v3 import RandomAccessCollectionResponseWithTotalHubDbTableRowV3
from hubspot.cms.hubdb.models.simple_user import SimpleUser
from hubspot.cms.hubdb.models.standard_error import StandardError
from hubspot.cms.hubdb.models.streaming_collection_response_with_total_hub_db_table_row_v3 import StreamingCollectionResponseWithTotalHubDbTableRowV3
from hubspot.cms.hubdb.models.unified_collection_response_with_total_base_hub_db_table_row_v3 import UnifiedCollectionResponseWithTotalBaseHubDbTableRowV3



try:
    import importlib.metadata as metadata
except ImportError:
    import importlib_metadata as metadata


class DiscoveryBase:
    def __init__(self, config):
        self.config = config

    def _configure_api_client(self, api_client_package, api_name):
        api_factory = self.config.get("api_factory") or self._default_api_factory
        config = {k: v for k, v in self.config.items() if k != "api_factory" and v is not None}
        return api_factory(api_client_package, api_name, config)

    @staticmethod
    def _default_api_factory(api_client_package, api_name, config):
        configuration = api_client_package.Configuration()
        for key in config:
            if key == "api_key":
                configuration.api_key["developer_hapikey"] = config["api_key"]
            elif key == "retry":
                configuration.retries = config["retry"]
            else:
                setattr(configuration, key, config[key])

        api_client = api_client_package.ApiClient(configuration=configuration)
        package_version = metadata.version("hubspot-api-client")
        api_client.user_agent = "hubspot-api-client-python; {0}".format(package_version)

        return getattr(api_client_package, api_name)(api_client=api_client)



# coding: utf-8

"""
    Automation Actions V4

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.automation.actions.configuration import Configuration


class PublicConditionalSingleFieldDependency(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"dependency_type": "str", "controlling_field_name": "str", "controlling_field_value": "str", "dependent_field_names": "list[str]"}

    attribute_map = {
        "dependency_type": "dependencyType",
        "controlling_field_name": "controllingFieldName",
        "controlling_field_value": "controllingFieldValue",
        "dependent_field_names": "dependentFieldNames",
    }

    def __init__(self, dependency_type="CONDITIONAL_SINGLE_FIELD", controlling_field_name=None, controlling_field_value=None, dependent_field_names=None, local_vars_configuration=None):  # noqa: E501
        """PublicConditionalSingleFieldDependency - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._dependency_type = None
        self._controlling_field_name = None
        self._controlling_field_value = None
        self._dependent_field_names = None
        self.discriminator = None

        self.dependency_type = dependency_type
        self.controlling_field_name = controlling_field_name
        self.controlling_field_value = controlling_field_value
        self.dependent_field_names = dependent_field_names

    @property
    def dependency_type(self):
        """Gets the dependency_type of this PublicConditionalSingleFieldDependency.  # noqa: E501


        :return: The dependency_type of this PublicConditionalSingleFieldDependency.  # noqa: E501
        :rtype: str
        """
        return self._dependency_type

    @dependency_type.setter
    def dependency_type(self, dependency_type):
        """Sets the dependency_type of this PublicConditionalSingleFieldDependency.


        :param dependency_type: The dependency_type of this PublicConditionalSingleFieldDependency.  # noqa: E501
        :type dependency_type: str
        """
        if self.local_vars_configuration.client_side_validation and dependency_type is None:  # noqa: E501
            raise ValueError("Invalid value for `dependency_type`, must not be `None`")  # noqa: E501
        allowed_values = ["CONDITIONAL_SINGLE_FIELD"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and dependency_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `dependency_type` ({0}), must be one of {1}".format(dependency_type, allowed_values))  # noqa: E501

        self._dependency_type = dependency_type

    @property
    def controlling_field_name(self):
        """Gets the controlling_field_name of this PublicConditionalSingleFieldDependency.  # noqa: E501


        :return: The controlling_field_name of this PublicConditionalSingleFieldDependency.  # noqa: E501
        :rtype: str
        """
        return self._controlling_field_name

    @controlling_field_name.setter
    def controlling_field_name(self, controlling_field_name):
        """Sets the controlling_field_name of this PublicConditionalSingleFieldDependency.


        :param controlling_field_name: The controlling_field_name of this PublicConditionalSingleFieldDependency.  # noqa: E501
        :type controlling_field_name: str
        """
        if self.local_vars_configuration.client_side_validation and controlling_field_name is None:  # noqa: E501
            raise ValueError("Invalid value for `controlling_field_name`, must not be `None`")  # noqa: E501

        self._controlling_field_name = controlling_field_name

    @property
    def controlling_field_value(self):
        """Gets the controlling_field_value of this PublicConditionalSingleFieldDependency.  # noqa: E501


        :return: The controlling_field_value of this PublicConditionalSingleFieldDependency.  # noqa: E501
        :rtype: str
        """
        return self._controlling_field_value

    @controlling_field_value.setter
    def controlling_field_value(self, controlling_field_value):
        """Sets the controlling_field_value of this PublicConditionalSingleFieldDependency.


        :param controlling_field_value: The controlling_field_value of this PublicConditionalSingleFieldDependency.  # noqa: E501
        :type controlling_field_value: str
        """
        if self.local_vars_configuration.client_side_validation and controlling_field_value is None:  # noqa: E501
            raise ValueError("Invalid value for `controlling_field_value`, must not be `None`")  # noqa: E501

        self._controlling_field_value = controlling_field_value

    @property
    def dependent_field_names(self):
        """Gets the dependent_field_names of this PublicConditionalSingleFieldDependency.  # noqa: E501


        :return: The dependent_field_names of this PublicConditionalSingleFieldDependency.  # noqa: E501
        :rtype: list[str]
        """
        return self._dependent_field_names

    @dependent_field_names.setter
    def dependent_field_names(self, dependent_field_names):
        """Sets the dependent_field_names of this PublicConditionalSingleFieldDependency.


        :param dependent_field_names: The dependent_field_names of this PublicConditionalSingleFieldDependency.  # noqa: E501
        :type dependent_field_names: list[str]
        """
        if self.local_vars_configuration.client_side_validation and dependent_field_names is None:  # noqa: E501
            raise ValueError("Invalid value for `dependent_field_names`, must not be `None`")  # noqa: E501

        self._dependent_field_names = dependent_field_names

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicConditionalSingleFieldDependency):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicConditionalSingleFieldDependency):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.crm.imports.api.core_api import CoreApi
from hubspot.crm.imports.api.public_imports_api import PublicImportsApi



import hubspot.marketing.emails as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def marketing_emails_api(self) -> api_client.MarketingEmailsApi:
        return self._configure_api_client(api_client, "MarketingEmailsApi")

    @property
    def statistics_api(self) -> api_client.StatisticsApi:
        return self._configure_api_client(api_client, "StatisticsApi")



# coding: utf-8

# flake8: noqa
"""
    Hubdb

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.cms.hubdb.models.batch_input_hub_db_table_row_batch_clone_request import BatchInputHubDbTableRowBatchCloneRequest
from hubspot.cms.hubdb.models.batch_input_hub_db_table_row_v3_batch_update_request import BatchInputHubDbTableRowV3BatchUpdateRequest
from hubspot.cms.hubdb.models.batch_input_hub_db_table_row_v3_request import BatchInputHubDbTableRowV3Request
from hubspot.cms.hubdb.models.batch_input_string import BatchInputString
from hubspot.cms.hubdb.models.batch_response_hub_db_table_row_v3 import BatchResponseHubDbTableRowV3
from hubspot.cms.hubdb.models.batch_response_hub_db_table_row_v3_with_errors import BatchResponseHubDbTableRowV3WithErrors
from hubspot.cms.hubdb.models.bounded_next_page import BoundedNextPage
from hubspot.cms.hubdb.models.bounded_paging import BoundedPaging
from hubspot.cms.hubdb.models.collection_response_with_total_hub_db_table_v3_forward_paging import CollectionResponseWithTotalHubDbTableV3ForwardPaging
from hubspot.cms.hubdb.models.column import Column
from hubspot.cms.hubdb.models.column_request import ColumnRequest
from hubspot.cms.hubdb.models.error import Error
from hubspot.cms.hubdb.models.error_detail import ErrorDetail
from hubspot.cms.hubdb.models.foreign_id import ForeignId
from hubspot.cms.hubdb.models.forward_paging import ForwardPaging
from hubspot.cms.hubdb.models.hub_db_table_clone_request import HubDbTableCloneRequest
from hubspot.cms.hubdb.models.hub_db_table_row_batch_clone_request import HubDbTableRowBatchCloneRequest
from hubspot.cms.hubdb.models.hub_db_table_row_v3 import HubDbTableRowV3
from hubspot.cms.hubdb.models.hub_db_table_row_v3_batch_update_request import HubDbTableRowV3BatchUpdateRequest
from hubspot.cms.hubdb.models.hub_db_table_row_v3_request import HubDbTableRowV3Request
from hubspot.cms.hubdb.models.hub_db_table_v3 import HubDbTableV3
from hubspot.cms.hubdb.models.hub_db_table_v3_request import HubDbTableV3Request
from hubspot.cms.hubdb.models.import_result import ImportResult
from hubspot.cms.hubdb.models.next_page import NextPage
from hubspot.cms.hubdb.models.option import Option
from hubspot.cms.hubdb.models.paging import Paging
from hubspot.cms.hubdb.models.previous_page import PreviousPage
from hubspot.cms.hubdb.models.random_access_collection_response_with_total_hub_db_table_row_v3 import RandomAccessCollectionResponseWithTotalHubDbTableRowV3
from hubspot.cms.hubdb.models.simple_user import SimpleUser
from hubspot.cms.hubdb.models.standard_error import StandardError
from hubspot.cms.hubdb.models.streaming_collection_response_with_total_hub_db_table_row_v3 import StreamingCollectionResponseWithTotalHubDbTableRowV3
from hubspot.cms.hubdb.models.unified_collection_response_with_total_base_hub_db_table_row_v3 import UnifiedCollectionResponseWithTotalBaseHubDbTableRowV3



# coding: utf-8

"""
    Pipelines

    Pipelines represent distinct stages in a workflow, like closing a deal or servicing a support ticket. These endpoints provide access to read and modify pipelines in HubSpot. Pipelines support `deals` and `tickets` object types.  ## Pipeline ID validation  When calling endpoints that take pipelineId as a parameter, that ID must correspond to an existing, un-archived pipeline. Otherwise the request will fail with a `404 Not Found` response.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.pipelines.configuration import Configuration


class PublicAuditInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"identifier": "str", "raw_object": "object", "from_user_id": "int", "portal_id": "int", "action": "str", "message": "str", "timestamp": "datetime"}

    attribute_map = {"identifier": "identifier", "raw_object": "rawObject", "from_user_id": "fromUserId", "portal_id": "portalId", "action": "action", "message": "message", "timestamp": "timestamp"}

    def __init__(self, identifier=None, raw_object=None, from_user_id=None, portal_id=None, action=None, message=None, timestamp=None, local_vars_configuration=None):  # noqa: E501
        """PublicAuditInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._identifier = None
        self._raw_object = None
        self._from_user_id = None
        self._portal_id = None
        self._action = None
        self._message = None
        self._timestamp = None
        self.discriminator = None

        self.identifier = identifier
        if raw_object is not None:
            self.raw_object = raw_object
        if from_user_id is not None:
            self.from_user_id = from_user_id
        self.portal_id = portal_id
        self.action = action
        if message is not None:
            self.message = message
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def identifier(self):
        """Gets the identifier of this PublicAuditInfo.  # noqa: E501


        :return: The identifier of this PublicAuditInfo.  # noqa: E501
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this PublicAuditInfo.


        :param identifier: The identifier of this PublicAuditInfo.  # noqa: E501
        :type identifier: str
        """
        if self.local_vars_configuration.client_side_validation and identifier is None:  # noqa: E501
            raise ValueError("Invalid value for `identifier`, must not be `None`")  # noqa: E501

        self._identifier = identifier

    @property
    def raw_object(self):
        """Gets the raw_object of this PublicAuditInfo.  # noqa: E501


        :return: The raw_object of this PublicAuditInfo.  # noqa: E501
        :rtype: object
        """
        return self._raw_object

    @raw_object.setter
    def raw_object(self, raw_object):
        """Sets the raw_object of this PublicAuditInfo.


        :param raw_object: The raw_object of this PublicAuditInfo.  # noqa: E501
        :type raw_object: object
        """

        self._raw_object = raw_object

    @property
    def from_user_id(self):
        """Gets the from_user_id of this PublicAuditInfo.  # noqa: E501


        :return: The from_user_id of this PublicAuditInfo.  # noqa: E501
        :rtype: int
        """
        return self._from_user_id

    @from_user_id.setter
    def from_user_id(self, from_user_id):
        """Sets the from_user_id of this PublicAuditInfo.


        :param from_user_id: The from_user_id of this PublicAuditInfo.  # noqa: E501
        :type from_user_id: int
        """

        self._from_user_id = from_user_id

    @property
    def portal_id(self):
        """Gets the portal_id of this PublicAuditInfo.  # noqa: E501


        :return: The portal_id of this PublicAuditInfo.  # noqa: E501
        :rtype: int
        """
        return self._portal_id

    @portal_id.setter
    def portal_id(self, portal_id):
        """Sets the portal_id of this PublicAuditInfo.


        :param portal_id: The portal_id of this PublicAuditInfo.  # noqa: E501
        :type portal_id: int
        """
        if self.local_vars_configuration.client_side_validation and portal_id is None:  # noqa: E501
            raise ValueError("Invalid value for `portal_id`, must not be `None`")  # noqa: E501

        self._portal_id = portal_id

    @property
    def action(self):
        """Gets the action of this PublicAuditInfo.  # noqa: E501


        :return: The action of this PublicAuditInfo.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this PublicAuditInfo.


        :param action: The action of this PublicAuditInfo.  # noqa: E501
        :type action: str
        """
        if self.local_vars_configuration.client_side_validation and action is None:  # noqa: E501
            raise ValueError("Invalid value for `action`, must not be `None`")  # noqa: E501

        self._action = action

    @property
    def message(self):
        """Gets the message of this PublicAuditInfo.  # noqa: E501


        :return: The message of this PublicAuditInfo.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this PublicAuditInfo.


        :param message: The message of this PublicAuditInfo.  # noqa: E501
        :type message: str
        """

        self._message = message

    @property
    def timestamp(self):
        """Gets the timestamp of this PublicAuditInfo.  # noqa: E501


        :return: The timestamp of this PublicAuditInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this PublicAuditInfo.


        :param timestamp: The timestamp of this PublicAuditInfo.  # noqa: E501
        :type timestamp: datetime
        """

        self._timestamp = timestamp

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicAuditInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicAuditInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Conversations Custom Channels

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from hubspot.conversations.custom_channels.models.channel_integration_message_egg import ChannelIntegrationMessageEgg
from hubspot.conversations.custom_channels.models.channel_integration_message_egg_attachments_inner import ChannelIntegrationMessageEggAttachmentsInner
from hubspot.conversations.custom_channels.models.channel_integration_participant import ChannelIntegrationParticipant
from hubspot.conversations.custom_channels.models.collection_response_with_total_public_channel_account_forward_paging import CollectionResponseWithTotalPublicChannelAccountForwardPaging
from hubspot.conversations.custom_channels.models.collection_response_with_total_public_channel_integration_channel_forward_paging import CollectionResponseWithTotalPublicChannelIntegrationChannelForwardPaging
from hubspot.conversations.custom_channels.models.contact_address import ContactAddress
from hubspot.conversations.custom_channels.models.contact_attachment import ContactAttachment
from hubspot.conversations.custom_channels.models.contact_email import ContactEmail
from hubspot.conversations.custom_channels.models.contact_name import ContactName
from hubspot.conversations.custom_channels.models.contact_org import ContactOrg
from hubspot.conversations.custom_channels.models.contact_phone import ContactPhone
from hubspot.conversations.custom_channels.models.contact_profile import ContactProfile
from hubspot.conversations.custom_channels.models.contact_url import ContactUrl
from hubspot.conversations.custom_channels.models.error import Error
from hubspot.conversations.custom_channels.models.error_detail import ErrorDetail
from hubspot.conversations.custom_channels.models.file_attachment import FileAttachment
from hubspot.conversations.custom_channels.models.forward_paging import ForwardPaging
from hubspot.conversations.custom_channels.models.location_attachment import LocationAttachment
from hubspot.conversations.custom_channels.models.message_header_attachment import MessageHeaderAttachment
from hubspot.conversations.custom_channels.models.next_page import NextPage
from hubspot.conversations.custom_channels.models.public_channel_account import PublicChannelAccount
from hubspot.conversations.custom_channels.models.public_channel_account_egg import PublicChannelAccountEgg
from hubspot.conversations.custom_channels.models.public_channel_account_staging_token import PublicChannelAccountStagingToken
from hubspot.conversations.custom_channels.models.public_channel_account_staging_token_update_request import PublicChannelAccountStagingTokenUpdateRequest
from hubspot.conversations.custom_channels.models.public_channel_account_update_request import PublicChannelAccountUpdateRequest
from hubspot.conversations.custom_channels.models.public_channel_integration_channel import PublicChannelIntegrationChannel
from hubspot.conversations.custom_channels.models.public_channel_integration_channel_capabilities import PublicChannelIntegrationChannelCapabilities
from hubspot.conversations.custom_channels.models.public_channel_integration_channel_create import PublicChannelIntegrationChannelCreate
from hubspot.conversations.custom_channels.models.public_channel_integration_channel_create_capabilities import PublicChannelIntegrationChannelCreateCapabilities
from hubspot.conversations.custom_channels.models.public_channel_integration_channel_patch import PublicChannelIntegrationChannelPatch
from hubspot.conversations.custom_channels.models.public_channel_integration_message_update_request import PublicChannelIntegrationMessageUpdateRequest
from hubspot.conversations.custom_channels.models.public_client import PublicClient
from hubspot.conversations.custom_channels.models.public_contact import PublicContact
from hubspot.conversations.custom_channels.models.public_conversations_message import PublicConversationsMessage
from hubspot.conversations.custom_channels.models.public_conversations_message_attachments_inner import PublicConversationsMessageAttachmentsInner
from hubspot.conversations.custom_channels.models.public_delivery_identifier import PublicDeliveryIdentifier
from hubspot.conversations.custom_channels.models.public_file import PublicFile
from hubspot.conversations.custom_channels.models.public_location import PublicLocation
from hubspot.conversations.custom_channels.models.public_message_failure_details import PublicMessageFailureDetails
from hubspot.conversations.custom_channels.models.public_message_header import PublicMessageHeader
from hubspot.conversations.custom_channels.models.public_message_status import PublicMessageStatus
from hubspot.conversations.custom_channels.models.public_quick_replies import PublicQuickReplies
from hubspot.conversations.custom_channels.models.public_recipient import PublicRecipient
from hubspot.conversations.custom_channels.models.public_sender import PublicSender
from hubspot.conversations.custom_channels.models.public_unsupported_content import PublicUnsupportedContent
from hubspot.conversations.custom_channels.models.public_whats_app_template_metadata import PublicWhatsAppTemplateMetadata
from hubspot.conversations.custom_channels.models.quick_replies_attachment import QuickRepliesAttachment
from hubspot.conversations.custom_channels.models.quick_reply import QuickReply
from hubspot.conversations.custom_channels.models.unsupported_content_attachment import UnsupportedContentAttachment



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicIndexedTimePoint(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"offset": "PublicIndexOffset", "timezone_source": "str", "index_reference": "PublicIndexedTimePointIndexReference", "time_type": "str", "zone_id": "str"}

    attribute_map = {"offset": "offset", "timezone_source": "timezoneSource", "index_reference": "indexReference", "time_type": "timeType", "zone_id": "zoneId"}

    def __init__(self, offset=None, timezone_source=None, index_reference=None, time_type="INDEXED", zone_id=None, local_vars_configuration=None):  # noqa: E501
        """PublicIndexedTimePoint - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._offset = None
        self._timezone_source = None
        self._index_reference = None
        self._time_type = None
        self._zone_id = None
        self.discriminator = None

        if offset is not None:
            self.offset = offset
        if timezone_source is not None:
            self.timezone_source = timezone_source
        self.index_reference = index_reference
        self.time_type = time_type
        self.zone_id = zone_id

    @property
    def offset(self):
        """Gets the offset of this PublicIndexedTimePoint.  # noqa: E501


        :return: The offset of this PublicIndexedTimePoint.  # noqa: E501
        :rtype: PublicIndexOffset
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this PublicIndexedTimePoint.


        :param offset: The offset of this PublicIndexedTimePoint.  # noqa: E501
        :type offset: PublicIndexOffset
        """

        self._offset = offset

    @property
    def timezone_source(self):
        """Gets the timezone_source of this PublicIndexedTimePoint.  # noqa: E501


        :return: The timezone_source of this PublicIndexedTimePoint.  # noqa: E501
        :rtype: str
        """
        return self._timezone_source

    @timezone_source.setter
    def timezone_source(self, timezone_source):
        """Sets the timezone_source of this PublicIndexedTimePoint.


        :param timezone_source: The timezone_source of this PublicIndexedTimePoint.  # noqa: E501
        :type timezone_source: str
        """

        self._timezone_source = timezone_source

    @property
    def index_reference(self):
        """Gets the index_reference of this PublicIndexedTimePoint.  # noqa: E501


        :return: The index_reference of this PublicIndexedTimePoint.  # noqa: E501
        :rtype: PublicIndexedTimePointIndexReference
        """
        return self._index_reference

    @index_reference.setter
    def index_reference(self, index_reference):
        """Sets the index_reference of this PublicIndexedTimePoint.


        :param index_reference: The index_reference of this PublicIndexedTimePoint.  # noqa: E501
        :type index_reference: PublicIndexedTimePointIndexReference
        """
        if self.local_vars_configuration.client_side_validation and index_reference is None:  # noqa: E501
            raise ValueError("Invalid value for `index_reference`, must not be `None`")  # noqa: E501

        self._index_reference = index_reference

    @property
    def time_type(self):
        """Gets the time_type of this PublicIndexedTimePoint.  # noqa: E501


        :return: The time_type of this PublicIndexedTimePoint.  # noqa: E501
        :rtype: str
        """
        return self._time_type

    @time_type.setter
    def time_type(self, time_type):
        """Sets the time_type of this PublicIndexedTimePoint.


        :param time_type: The time_type of this PublicIndexedTimePoint.  # noqa: E501
        :type time_type: str
        """
        if self.local_vars_configuration.client_side_validation and time_type is None:  # noqa: E501
            raise ValueError("Invalid value for `time_type`, must not be `None`")  # noqa: E501
        allowed_values = ["INDEXED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and time_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `time_type` ({0}), must be one of {1}".format(time_type, allowed_values))  # noqa: E501

        self._time_type = time_type

    @property
    def zone_id(self):
        """Gets the zone_id of this PublicIndexedTimePoint.  # noqa: E501


        :return: The zone_id of this PublicIndexedTimePoint.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this PublicIndexedTimePoint.


        :param zone_id: The zone_id of this PublicIndexedTimePoint.  # noqa: E501
        :type zone_id: str
        """
        if self.local_vars_configuration.client_side_validation and zone_id is None:  # noqa: E501
            raise ValueError("Invalid value for `zone_id`, must not be `None`")  # noqa: E501

        self._zone_id = zone_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicIndexedTimePoint):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicIndexedTimePoint):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Posts

    Use these endpoints for interacting with Blog Posts, Blog Authors, and Blog Tags  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.cms.blogs.blog_posts.models.angle import Angle
from hubspot.cms.blogs.blog_posts.models.attach_to_lang_primary_request_v_next import AttachToLangPrimaryRequestVNext
from hubspot.cms.blogs.blog_posts.models.background_image import BackgroundImage
from hubspot.cms.blogs.blog_posts.models.batch_input_blog_post import BatchInputBlogPost
from hubspot.cms.blogs.blog_posts.models.batch_input_json_node import BatchInputJsonNode
from hubspot.cms.blogs.blog_posts.models.batch_input_string import BatchInputString
from hubspot.cms.blogs.blog_posts.models.batch_response_blog_post import BatchResponseBlogPost
from hubspot.cms.blogs.blog_posts.models.batch_response_blog_post_with_errors import BatchResponseBlogPostWithErrors
from hubspot.cms.blogs.blog_posts.models.blog_post import BlogPost
from hubspot.cms.blogs.blog_posts.models.blog_post_language_clone_request_v_next import BlogPostLanguageCloneRequestVNext
from hubspot.cms.blogs.blog_posts.models.breakpoint_styles import BreakpointStyles
from hubspot.cms.blogs.blog_posts.models.collection_response_with_total_blog_post_forward_paging import CollectionResponseWithTotalBlogPostForwardPaging
from hubspot.cms.blogs.blog_posts.models.collection_response_with_total_version_blog_post import CollectionResponseWithTotalVersionBlogPost
from hubspot.cms.blogs.blog_posts.models.color_stop import ColorStop
from hubspot.cms.blogs.blog_posts.models.content_clone_request_v_next import ContentCloneRequestVNext
from hubspot.cms.blogs.blog_posts.models.content_language_variation import ContentLanguageVariation
from hubspot.cms.blogs.blog_posts.models.content_schedule_request_v_next import ContentScheduleRequestVNext
from hubspot.cms.blogs.blog_posts.models.detach_from_lang_group_request_v_next import DetachFromLangGroupRequestVNext
from hubspot.cms.blogs.blog_posts.models.error import Error
from hubspot.cms.blogs.blog_posts.models.error_detail import ErrorDetail
from hubspot.cms.blogs.blog_posts.models.forward_paging import ForwardPaging
from hubspot.cms.blogs.blog_posts.models.gradient import Gradient
from hubspot.cms.blogs.blog_posts.models.layout_section import LayoutSection
from hubspot.cms.blogs.blog_posts.models.next_page import NextPage
from hubspot.cms.blogs.blog_posts.models.paging import Paging
from hubspot.cms.blogs.blog_posts.models.previous_page import PreviousPage
from hubspot.cms.blogs.blog_posts.models.rgba_color import RGBAColor
from hubspot.cms.blogs.blog_posts.models.row_meta_data import RowMetaData
from hubspot.cms.blogs.blog_posts.models.set_new_language_primary_request_v_next import SetNewLanguagePrimaryRequestVNext
from hubspot.cms.blogs.blog_posts.models.side_or_corner import SideOrCorner
from hubspot.cms.blogs.blog_posts.models.standard_error import StandardError
from hubspot.cms.blogs.blog_posts.models.styles import Styles
from hubspot.cms.blogs.blog_posts.models.update_languages_request_v_next import UpdateLanguagesRequestVNext
from hubspot.cms.blogs.blog_posts.models.version_blog_post import VersionBlogPost
from hubspot.cms.blogs.blog_posts.models.version_user import VersionUser



import hubspot.crm.pipelines as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):

    @property
    def pipeline_audits_api(self) -> api_client.PipelineAuditsApi:
        return self._configure_api_client(api_client, "PipelineAuditsApi")

    @property
    def pipeline_stage_audits_api(self) -> api_client.PipelineStageAuditsApi:
        return self._configure_api_client(api_client, "PipelineStageAuditsApi")

    @property
    def pipeline_stages_api(self) -> api_client.PipelineStagesApi:
        return self._configure_api_client(api_client, "PipelineStagesApi")

    @property
    def pipelines_api(self) -> api_client.PipelinesApi:
        return self._configure_api_client(api_client, "PipelinesApi")



# coding: utf-8

"""
    Marketing Events

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.events.configuration import Configuration


class MarketingEventPublicDefaultResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "event_organizer": "str",
        "event_url": "str",
        "event_type": "str",
        "event_completed": "bool",
        "end_date_time": "datetime",
        "created_at": "datetime",
        "start_date_time": "datetime",
        "custom_properties": "list[PropertyValue]",
        "event_cancelled": "bool",
        "event_description": "str",
        "event_name": "str",
        "id": "str",
        "object_id": "str",
        "updated_at": "datetime",
    }

    attribute_map = {
        "event_organizer": "eventOrganizer",
        "event_url": "eventUrl",
        "event_type": "eventType",
        "event_completed": "eventCompleted",
        "end_date_time": "endDateTime",
        "created_at": "createdAt",
        "start_date_time": "startDateTime",
        "custom_properties": "customProperties",
        "event_cancelled": "eventCancelled",
        "event_description": "eventDescription",
        "event_name": "eventName",
        "id": "id",
        "object_id": "objectId",
        "updated_at": "updatedAt",
    }

    def __init__(
        self,
        event_organizer=None,
        event_url=None,
        event_type=None,
        event_completed=None,
        end_date_time=None,
        created_at=None,
        start_date_time=None,
        custom_properties=None,
        event_cancelled=None,
        event_description=None,
        event_name=None,
        id=None,
        object_id=None,
        updated_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """MarketingEventPublicDefaultResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._event_organizer = None
        self._event_url = None
        self._event_type = None
        self._event_completed = None
        self._end_date_time = None
        self._created_at = None
        self._start_date_time = None
        self._custom_properties = None
        self._event_cancelled = None
        self._event_description = None
        self._event_name = None
        self._id = None
        self._object_id = None
        self._updated_at = None
        self.discriminator = None

        self.event_organizer = event_organizer
        if event_url is not None:
            self.event_url = event_url
        if event_type is not None:
            self.event_type = event_type
        if event_completed is not None:
            self.event_completed = event_completed
        if end_date_time is not None:
            self.end_date_time = end_date_time
        self.created_at = created_at
        if start_date_time is not None:
            self.start_date_time = start_date_time
        if custom_properties is not None:
            self.custom_properties = custom_properties
        if event_cancelled is not None:
            self.event_cancelled = event_cancelled
        if event_description is not None:
            self.event_description = event_description
        self.event_name = event_name
        self.id = id
        if object_id is not None:
            self.object_id = object_id
        self.updated_at = updated_at

    @property
    def event_organizer(self):
        """Gets the event_organizer of this MarketingEventPublicDefaultResponse.  # noqa: E501

        The name of the organizer of the marketing event.  # noqa: E501

        :return: The event_organizer of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: str
        """
        return self._event_organizer

    @event_organizer.setter
    def event_organizer(self, event_organizer):
        """Sets the event_organizer of this MarketingEventPublicDefaultResponse.

        The name of the organizer of the marketing event.  # noqa: E501

        :param event_organizer: The event_organizer of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type event_organizer: str
        """
        if self.local_vars_configuration.client_side_validation and event_organizer is None:  # noqa: E501
            raise ValueError("Invalid value for `event_organizer`, must not be `None`")  # noqa: E501

        self._event_organizer = event_organizer

    @property
    def event_url(self):
        """Gets the event_url of this MarketingEventPublicDefaultResponse.  # noqa: E501

        A URL in the external event application where the marketing event can be managed.  # noqa: E501

        :return: The event_url of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: str
        """
        return self._event_url

    @event_url.setter
    def event_url(self, event_url):
        """Sets the event_url of this MarketingEventPublicDefaultResponse.

        A URL in the external event application where the marketing event can be managed.  # noqa: E501

        :param event_url: The event_url of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type event_url: str
        """

        self._event_url = event_url

    @property
    def event_type(self):
        """Gets the event_type of this MarketingEventPublicDefaultResponse.  # noqa: E501

        The type of the marketing event.  # noqa: E501

        :return: The event_type of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this MarketingEventPublicDefaultResponse.

        The type of the marketing event.  # noqa: E501

        :param event_type: The event_type of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type event_type: str
        """

        self._event_type = event_type

    @property
    def event_completed(self):
        """Gets the event_completed of this MarketingEventPublicDefaultResponse.  # noqa: E501


        :return: The event_completed of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: bool
        """
        return self._event_completed

    @event_completed.setter
    def event_completed(self, event_completed):
        """Sets the event_completed of this MarketingEventPublicDefaultResponse.


        :param event_completed: The event_completed of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type event_completed: bool
        """

        self._event_completed = event_completed

    @property
    def end_date_time(self):
        """Gets the end_date_time of this MarketingEventPublicDefaultResponse.  # noqa: E501

        The end date and time of the marketing event.  # noqa: E501

        :return: The end_date_time of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date_time

    @end_date_time.setter
    def end_date_time(self, end_date_time):
        """Sets the end_date_time of this MarketingEventPublicDefaultResponse.

        The end date and time of the marketing event.  # noqa: E501

        :param end_date_time: The end_date_time of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type end_date_time: datetime
        """

        self._end_date_time = end_date_time

    @property
    def created_at(self):
        """Gets the created_at of this MarketingEventPublicDefaultResponse.  # noqa: E501

          # noqa: E501

        :return: The created_at of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this MarketingEventPublicDefaultResponse.

          # noqa: E501

        :param created_at: The created_at of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def start_date_time(self):
        """Gets the start_date_time of this MarketingEventPublicDefaultResponse.  # noqa: E501

        The start date and time of the marketing event.  # noqa: E501

        :return: The start_date_time of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date_time

    @start_date_time.setter
    def start_date_time(self, start_date_time):
        """Sets the start_date_time of this MarketingEventPublicDefaultResponse.

        The start date and time of the marketing event.  # noqa: E501

        :param start_date_time: The start_date_time of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type start_date_time: datetime
        """

        self._start_date_time = start_date_time

    @property
    def custom_properties(self):
        """Gets the custom_properties of this MarketingEventPublicDefaultResponse.  # noqa: E501

        A list of PropertyValues. These can be whatever kind of property names and values you want. However, they must already exist on the HubSpot account's definition of the MarketingEvent Object. If they don't they will be filtered out and not set. In order to do this you'll need to create a new PropertyGroup on the HubSpot account's MarketingEvent object for your specific app and create the Custom Property you want to track on that HubSpot account. Do not create any new default properties on the MarketingEvent object as that will apply to all HubSpot accounts.   # noqa: E501

        :return: The custom_properties of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: list[PropertyValue]
        """
        return self._custom_properties

    @custom_properties.setter
    def custom_properties(self, custom_properties):
        """Sets the custom_properties of this MarketingEventPublicDefaultResponse.

        A list of PropertyValues. These can be whatever kind of property names and values you want. However, they must already exist on the HubSpot account's definition of the MarketingEvent Object. If they don't they will be filtered out and not set. In order to do this you'll need to create a new PropertyGroup on the HubSpot account's MarketingEvent object for your specific app and create the Custom Property you want to track on that HubSpot account. Do not create any new default properties on the MarketingEvent object as that will apply to all HubSpot accounts.   # noqa: E501

        :param custom_properties: The custom_properties of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type custom_properties: list[PropertyValue]
        """

        self._custom_properties = custom_properties

    @property
    def event_cancelled(self):
        """Gets the event_cancelled of this MarketingEventPublicDefaultResponse.  # noqa: E501

        Indicates if the marketing event has been cancelled.  # noqa: E501

        :return: The event_cancelled of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: bool
        """
        return self._event_cancelled

    @event_cancelled.setter
    def event_cancelled(self, event_cancelled):
        """Sets the event_cancelled of this MarketingEventPublicDefaultResponse.

        Indicates if the marketing event has been cancelled.  # noqa: E501

        :param event_cancelled: The event_cancelled of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type event_cancelled: bool
        """

        self._event_cancelled = event_cancelled

    @property
    def event_description(self):
        """Gets the event_description of this MarketingEventPublicDefaultResponse.  # noqa: E501

        The description of the marketing event.  # noqa: E501

        :return: The event_description of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: str
        """
        return self._event_description

    @event_description.setter
    def event_description(self, event_description):
        """Sets the event_description of this MarketingEventPublicDefaultResponse.

        The description of the marketing event.  # noqa: E501

        :param event_description: The event_description of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type event_description: str
        """

        self._event_description = event_description

    @property
    def event_name(self):
        """Gets the event_name of this MarketingEventPublicDefaultResponse.  # noqa: E501

        The name of the marketing event.  # noqa: E501

        :return: The event_name of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this MarketingEventPublicDefaultResponse.

        The name of the marketing event.  # noqa: E501

        :param event_name: The event_name of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type event_name: str
        """
        if self.local_vars_configuration.client_side_validation and event_name is None:  # noqa: E501
            raise ValueError("Invalid value for `event_name`, must not be `None`")  # noqa: E501

        self._event_name = event_name

    @property
    def id(self):
        """Gets the id of this MarketingEventPublicDefaultResponse.  # noqa: E501

          # noqa: E501

        :return: The id of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MarketingEventPublicDefaultResponse.

          # noqa: E501

        :param id: The id of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def object_id(self):
        """Gets the object_id of this MarketingEventPublicDefaultResponse.  # noqa: E501


        :return: The object_id of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this MarketingEventPublicDefaultResponse.


        :param object_id: The object_id of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type object_id: str
        """

        self._object_id = object_id

    @property
    def updated_at(self):
        """Gets the updated_at of this MarketingEventPublicDefaultResponse.  # noqa: E501

          # noqa: E501

        :return: The updated_at of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this MarketingEventPublicDefaultResponse.

          # noqa: E501

        :param updated_at: The updated_at of this MarketingEventPublicDefaultResponse.  # noqa: E501
        :type updated_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MarketingEventPublicDefaultResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MarketingEventPublicDefaultResponse):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.cms.site_search as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def public_api(self) -> api_client.PublicApi:
        return self._configure_api_client(api_client, "PublicApi")



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class MembershipsUpdateResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"record_ids_removed": "list[str]", "records_ids_added": "list[str]", "record_ids_missing": "list[str]"}

    attribute_map = {"record_ids_removed": "recordIdsRemoved", "records_ids_added": "recordsIdsAdded", "record_ids_missing": "recordIdsMissing"}

    def __init__(self, record_ids_removed=None, records_ids_added=None, record_ids_missing=None, local_vars_configuration=None):  # noqa: E501
        """MembershipsUpdateResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._record_ids_removed = None
        self._records_ids_added = None
        self._record_ids_missing = None
        self.discriminator = None

        self.record_ids_removed = record_ids_removed
        self.records_ids_added = records_ids_added
        self.record_ids_missing = record_ids_missing

    @property
    def record_ids_removed(self):
        """Gets the record_ids_removed of this MembershipsUpdateResponse.  # noqa: E501

        The IDs of the records that were `removed` from the list.  # noqa: E501

        :return: The record_ids_removed of this MembershipsUpdateResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._record_ids_removed

    @record_ids_removed.setter
    def record_ids_removed(self, record_ids_removed):
        """Sets the record_ids_removed of this MembershipsUpdateResponse.

        The IDs of the records that were `removed` from the list.  # noqa: E501

        :param record_ids_removed: The record_ids_removed of this MembershipsUpdateResponse.  # noqa: E501
        :type record_ids_removed: list[str]
        """
        if self.local_vars_configuration.client_side_validation and record_ids_removed is None:  # noqa: E501
            raise ValueError("Invalid value for `record_ids_removed`, must not be `None`")  # noqa: E501

        self._record_ids_removed = record_ids_removed

    @property
    def records_ids_added(self):
        """Gets the records_ids_added of this MembershipsUpdateResponse.  # noqa: E501


        :return: The records_ids_added of this MembershipsUpdateResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._records_ids_added

    @records_ids_added.setter
    def records_ids_added(self, records_ids_added):
        """Sets the records_ids_added of this MembershipsUpdateResponse.


        :param records_ids_added: The records_ids_added of this MembershipsUpdateResponse.  # noqa: E501
        :type records_ids_added: list[str]
        """
        if self.local_vars_configuration.client_side_validation and records_ids_added is None:  # noqa: E501
            raise ValueError("Invalid value for `records_ids_added`, must not be `None`")  # noqa: E501

        self._records_ids_added = records_ids_added

    @property
    def record_ids_missing(self):
        """Gets the record_ids_missing of this MembershipsUpdateResponse.  # noqa: E501

        The IDs of the records that were `missing` (e.g. did not exist in the portal) and so were not `added` or `removed`.  # noqa: E501

        :return: The record_ids_missing of this MembershipsUpdateResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._record_ids_missing

    @record_ids_missing.setter
    def record_ids_missing(self, record_ids_missing):
        """Sets the record_ids_missing of this MembershipsUpdateResponse.

        The IDs of the records that were `missing` (e.g. did not exist in the portal) and so were not `added` or `removed`.  # noqa: E501

        :param record_ids_missing: The record_ids_missing of this MembershipsUpdateResponse.  # noqa: E501
        :type record_ids_missing: list[str]
        """
        if self.local_vars_configuration.client_side_validation and record_ids_missing is None:  # noqa: E501
            raise ValueError("Invalid value for `record_ids_missing`, must not be `None`")  # noqa: E501

        self._record_ids_missing = record_ids_missing

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MembershipsUpdateResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MembershipsUpdateResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    CRM Exports

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.exports.models.action_response_with_single_result_uri import ActionResponseWithSingleResultURI
from hubspot.crm.exports.models.error import Error
from hubspot.crm.exports.models.error_detail import ErrorDetail
from hubspot.crm.exports.models.filter import Filter
from hubspot.crm.exports.models.public_crm_search_request import PublicCrmSearchRequest
from hubspot.crm.exports.models.public_export_list_request import PublicExportListRequest
from hubspot.crm.exports.models.public_export_list_request_all_of import PublicExportListRequestAllOf
from hubspot.crm.exports.models.public_export_request import PublicExportRequest
from hubspot.crm.exports.models.public_export_view_request import PublicExportViewRequest
from hubspot.crm.exports.models.public_export_view_request_all_of import PublicExportViewRequestAllOf
from hubspot.crm.exports.models.standard_error import StandardError
from hubspot.crm.exports.models.task_locator import TaskLocator



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicRangedTimeOperation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "upper_bound_endpoint_behavior": "str",
        "include_objects_with_no_value_set": "bool",
        "upper_bound_time_point": "PublicTimePointOperationTimePoint",
        "property_parser": "str",
        "operation_type": "str",
        "type": "str",
        "lower_bound_endpoint_behavior": "str",
        "operator": "str",
        "lower_bound_time_point": "PublicTimePointOperationTimePoint",
    }

    attribute_map = {
        "upper_bound_endpoint_behavior": "upperBoundEndpointBehavior",
        "include_objects_with_no_value_set": "includeObjectsWithNoValueSet",
        "upper_bound_time_point": "upperBoundTimePoint",
        "property_parser": "propertyParser",
        "operation_type": "operationType",
        "type": "type",
        "lower_bound_endpoint_behavior": "lowerBoundEndpointBehavior",
        "operator": "operator",
        "lower_bound_time_point": "lowerBoundTimePoint",
    }

    def __init__(
        self,
        upper_bound_endpoint_behavior=None,
        include_objects_with_no_value_set=None,
        upper_bound_time_point=None,
        property_parser=None,
        operation_type=None,
        type="TIME_RANGED",
        lower_bound_endpoint_behavior=None,
        operator=None,
        lower_bound_time_point=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicRangedTimeOperation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._upper_bound_endpoint_behavior = None
        self._include_objects_with_no_value_set = None
        self._upper_bound_time_point = None
        self._property_parser = None
        self._operation_type = None
        self._type = None
        self._lower_bound_endpoint_behavior = None
        self._operator = None
        self._lower_bound_time_point = None
        self.discriminator = None

        if upper_bound_endpoint_behavior is not None:
            self.upper_bound_endpoint_behavior = upper_bound_endpoint_behavior
        self.include_objects_with_no_value_set = include_objects_with_no_value_set
        self.upper_bound_time_point = upper_bound_time_point
        if property_parser is not None:
            self.property_parser = property_parser
        self.operation_type = operation_type
        self.type = type
        if lower_bound_endpoint_behavior is not None:
            self.lower_bound_endpoint_behavior = lower_bound_endpoint_behavior
        self.operator = operator
        self.lower_bound_time_point = lower_bound_time_point

    @property
    def upper_bound_endpoint_behavior(self):
        """Gets the upper_bound_endpoint_behavior of this PublicRangedTimeOperation.  # noqa: E501


        :return: The upper_bound_endpoint_behavior of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: str
        """
        return self._upper_bound_endpoint_behavior

    @upper_bound_endpoint_behavior.setter
    def upper_bound_endpoint_behavior(self, upper_bound_endpoint_behavior):
        """Sets the upper_bound_endpoint_behavior of this PublicRangedTimeOperation.


        :param upper_bound_endpoint_behavior: The upper_bound_endpoint_behavior of this PublicRangedTimeOperation.  # noqa: E501
        :type upper_bound_endpoint_behavior: str
        """

        self._upper_bound_endpoint_behavior = upper_bound_endpoint_behavior

    @property
    def include_objects_with_no_value_set(self):
        """Gets the include_objects_with_no_value_set of this PublicRangedTimeOperation.  # noqa: E501


        :return: The include_objects_with_no_value_set of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: bool
        """
        return self._include_objects_with_no_value_set

    @include_objects_with_no_value_set.setter
    def include_objects_with_no_value_set(self, include_objects_with_no_value_set):
        """Sets the include_objects_with_no_value_set of this PublicRangedTimeOperation.


        :param include_objects_with_no_value_set: The include_objects_with_no_value_set of this PublicRangedTimeOperation.  # noqa: E501
        :type include_objects_with_no_value_set: bool
        """
        if self.local_vars_configuration.client_side_validation and include_objects_with_no_value_set is None:  # noqa: E501
            raise ValueError("Invalid value for `include_objects_with_no_value_set`, must not be `None`")  # noqa: E501

        self._include_objects_with_no_value_set = include_objects_with_no_value_set

    @property
    def upper_bound_time_point(self):
        """Gets the upper_bound_time_point of this PublicRangedTimeOperation.  # noqa: E501


        :return: The upper_bound_time_point of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: PublicTimePointOperationTimePoint
        """
        return self._upper_bound_time_point

    @upper_bound_time_point.setter
    def upper_bound_time_point(self, upper_bound_time_point):
        """Sets the upper_bound_time_point of this PublicRangedTimeOperation.


        :param upper_bound_time_point: The upper_bound_time_point of this PublicRangedTimeOperation.  # noqa: E501
        :type upper_bound_time_point: PublicTimePointOperationTimePoint
        """
        if self.local_vars_configuration.client_side_validation and upper_bound_time_point is None:  # noqa: E501
            raise ValueError("Invalid value for `upper_bound_time_point`, must not be `None`")  # noqa: E501

        self._upper_bound_time_point = upper_bound_time_point

    @property
    def property_parser(self):
        """Gets the property_parser of this PublicRangedTimeOperation.  # noqa: E501


        :return: The property_parser of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: str
        """
        return self._property_parser

    @property_parser.setter
    def property_parser(self, property_parser):
        """Sets the property_parser of this PublicRangedTimeOperation.


        :param property_parser: The property_parser of this PublicRangedTimeOperation.  # noqa: E501
        :type property_parser: str
        """

        self._property_parser = property_parser

    @property
    def operation_type(self):
        """Gets the operation_type of this PublicRangedTimeOperation.  # noqa: E501


        :return: The operation_type of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: str
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """Sets the operation_type of this PublicRangedTimeOperation.


        :param operation_type: The operation_type of this PublicRangedTimeOperation.  # noqa: E501
        :type operation_type: str
        """
        if self.local_vars_configuration.client_side_validation and operation_type is None:  # noqa: E501
            raise ValueError("Invalid value for `operation_type`, must not be `None`")  # noqa: E501

        self._operation_type = operation_type

    @property
    def type(self):
        """Gets the type of this PublicRangedTimeOperation.  # noqa: E501


        :return: The type of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PublicRangedTimeOperation.


        :param type: The type of this PublicRangedTimeOperation.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["TIME_RANGED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `type` ({0}), must be one of {1}".format(type, allowed_values))  # noqa: E501

        self._type = type

    @property
    def lower_bound_endpoint_behavior(self):
        """Gets the lower_bound_endpoint_behavior of this PublicRangedTimeOperation.  # noqa: E501


        :return: The lower_bound_endpoint_behavior of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: str
        """
        return self._lower_bound_endpoint_behavior

    @lower_bound_endpoint_behavior.setter
    def lower_bound_endpoint_behavior(self, lower_bound_endpoint_behavior):
        """Sets the lower_bound_endpoint_behavior of this PublicRangedTimeOperation.


        :param lower_bound_endpoint_behavior: The lower_bound_endpoint_behavior of this PublicRangedTimeOperation.  # noqa: E501
        :type lower_bound_endpoint_behavior: str
        """

        self._lower_bound_endpoint_behavior = lower_bound_endpoint_behavior

    @property
    def operator(self):
        """Gets the operator of this PublicRangedTimeOperation.  # noqa: E501


        :return: The operator of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PublicRangedTimeOperation.


        :param operator: The operator of this PublicRangedTimeOperation.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501

        self._operator = operator

    @property
    def lower_bound_time_point(self):
        """Gets the lower_bound_time_point of this PublicRangedTimeOperation.  # noqa: E501


        :return: The lower_bound_time_point of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: PublicTimePointOperationTimePoint
        """
        return self._lower_bound_time_point

    @lower_bound_time_point.setter
    def lower_bound_time_point(self, lower_bound_time_point):
        """Sets the lower_bound_time_point of this PublicRangedTimeOperation.


        :param lower_bound_time_point: The lower_bound_time_point of this PublicRangedTimeOperation.  # noqa: E501
        :type lower_bound_time_point: PublicTimePointOperationTimePoint
        """
        if self.local_vars_configuration.client_side_validation and lower_bound_time_point is None:  # noqa: E501
            raise ValueError("Invalid value for `lower_bound_time_point`, must not be `None`")  # noqa: E501

        self._lower_bound_time_point = lower_bound_time_point

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicRangedTimeOperation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicRangedTimeOperation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Events Send Event Completions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.events.send.api.basic_api import BasicApi
from hubspot.events.send.api.batch_api import BatchApi

# import ApiClient
from hubspot.events.send.api_client import ApiClient
from hubspot.events.send.configuration import Configuration
from hubspot.events.send.exceptions import OpenApiException
from hubspot.events.send.exceptions import ApiTypeError
from hubspot.events.send.exceptions import ApiValueError
from hubspot.events.send.exceptions import ApiKeyError
from hubspot.events.send.exceptions import ApiAttributeError
from hubspot.events.send.exceptions import ApiException

# import models into sdk package
from hubspot.events.send.models.batched_behavioral_event_http_completion_request import BatchedBehavioralEventHttpCompletionRequest
from hubspot.events.send.models.behavioral_event_http_completion_request import BehavioralEventHttpCompletionRequest
from hubspot.events.send.models.error import Error
from hubspot.events.send.models.error_detail import ErrorDetail



import hubspot.cms.audit_logs as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def audit_logs_api(self) -> api_client.AuditLogsApi:
        return self._configure_api_client(api_client, "AuditLogsApi")
